```
Usage: vcd profile [OPTIONS] COMMAND [ARGS]...

  Manage user profiles



Options:
  -h, --help  Show this message and exit.

Commands:
  extension  work with vcd-cli extensions
  info       show details of current profile

```
